@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 from enum import Enum
 from json.decoder import JSONDecodeError
-from typing import Any, Dict, List, Optional, Union
+from typing import Any
 
 from requests import Session
 
-from .constants import Constants
-from .errors import GraphqlError, IkeaApiError, UnauthorizedError
+from ikea_api.constants import Constants
+from ikea_api.errors import GraphqlError, IkeaApiError, UnauthorizedError
 
 
 class Method(Enum):
@@ -16,7 +18,7 @@ class Method(Enum):
 class API:
     """Generic API class"""
 
-    def __init__(self, token: Union[str, None], endpoint: str):
+    def __init__(self, token: str, endpoint: str):
         self._token, self._endpoint = token, endpoint
 
         self._session = Session()
@@ -33,24 +35,22 @@ class API:
         if token is not None:
             self._session.headers["Authorization"] = "Bearer " + token
 
-    def _error_handler(self, status_code: int, response_json: Any):
+    def _error_handler(self, status_code: int, response: Any):
         pass
 
-    def _basic_error_handler(
-        self, status_code: int, response_json: Union[Any, Dict[str, Any]]
-    ):
+    def _basic_error_handler(self, status_code: int, response: Any | dict[str, Any]):
         if status_code == 401:  # Token did not passed
-            raise UnauthorizedError(response_json)
+            raise UnauthorizedError(response)
 
-        if "errors" in response_json:  # GraphQL error
-            raise GraphqlError(response_json)
+        if "errors" in response:  # GraphQL error
+            raise GraphqlError(response)
 
     def _call_api(
         self,
-        endpoint: Optional[str] = None,
+        endpoint: str | None = None,
         method: Method = Method.POST,
-        headers: Optional[Dict[str, str]] = None,
-        data: Optional[Union[Dict[Any, Any], List[Any]]] = None,
+        headers: dict[str, str] | None = None,
+        data: dict[Any, Any] | list[Any] | None = None,
     ):
         """Wrapper for request's post/get with error handling"""
         if not endpoint:
@@ -62,14 +62,14 @@ class API:
             response = self._session.post(endpoint, headers=headers, json=data)
 
         try:
-            response_json: Dict[Any, Any] = response.json()
+            response_dict: Any = response.json()
         except JSONDecodeError:
             raise IkeaApiError(response.status_code, response.text)
 
-        self._basic_error_handler(response.status_code, response_json)
-        self._error_handler(response.status_code, response_json)
+        self._basic_error_handler(response.status_code, response_dict)
+        self._error_handler(response.status_code, response_dict)
 
         if not response.ok:
             raise IkeaApiError(response.status_code, response.text)
 
-        return response_json
+        return response_dict
