@@ -1,14 +1,13 @@
-from typing import List, Union
+from __future__ import annotations
 
 from requests import Session
 
 from ikea_api.constants import Constants, Secrets
+from ikea_api.endpoints.item import generic_item_fetcher
 from ikea_api.errors import ItemFetchError
 
-from . import generic_item_fetcher
 
-
-def _fetch_items_specs(session: Session, items: List[str]):
+def _fetch_items_specs(session: Session, items: list[str]):
     url = (
         "https://api.ingka.ikea.com/salesitem/communications/"
         + Constants.COUNTRY_CODE
@@ -18,7 +17,7 @@ def _fetch_items_specs(session: Session, items: List[str]):
     params = {"itemNos": ",".join(items)}
     response = session.get(url, params=params)
     r_json = response.json()
-    if not "data" in r_json and "error" in r_json:
+    if "data" not in r_json and "error" in r_json:
         err_msg = None
         if "message" in r_json["error"]:
             error = r_json["error"]
@@ -37,7 +36,7 @@ def _fetch_items_specs(session: Session, items: List[str]):
     return r_json
 
 
-def fetch(items: Union[str, List[str]]):
+def fetch(items: str | list[str]):
     headers = {
         "Accept": "*/*",
         "Referer": f"{Constants.BASE_URL}/{Constants.COUNTRY_CODE}/{Constants.LANGUAGE_CODE}/order/delivery/",
